<?php


namespace XLite\Module\Pmall\CleanURL\Model\Repo;

/**
 * Clean URL repository
 */
abstract class CleanURL extends \XLite\Model\Repo\CleanURL implements \XLite\Base\IDecorator
{	
    /**
     * Default extension
     */
    const CLEAN_URL_DEFAULT_EXTENSION = '';
	
    /**
     * Returns product url regexp pattern
     *
     * @return string
     */
    protected function getPatternProduct()
    {
        return $this->getCommonPattern();
    }

	
    /**
     * Post process clean URL
     *
     * @param string               $url    URL
     * @param \XLite\Model\AEntity $entity Entity
     *
     * @return string
     */
    protected function postProcessURLProduct($url, $entity)
    {
        return $url;
    }

	
    /**
     * Parse clean URL
     * Return array((string) $target, (array) $params)
     *
     * @param string $url  Main part of a clean URL
     * @param string $last First part before the "url" OPTIONAL
     * @param string $rest Part before the "url" and "last" OPTIONAL
     * @param string $ext  Extension OPTIONAL
     *
     * @return array
     */
    protected function parseURLProduct($url, $last = '', $rest = '', $ext = '')
    {
        return $this->findByURL('product', $url);
    }


    /**
     * Parse clean URL
     * Return array((string) $target, (array) $params)
     *
     * @param string $url  Main part of a clean URL
     * @param string $last First part before the "url" OPTIONAL
     * @param string $rest Part before the "url" and "last" OPTIONAL
     * @param string $ext  Extension OPTIONAL
     *
     * @return array
     */
    protected function parseURLCategory($url, $last = '', $rest = '', $ext = '')
    {
        return $this->findByURL('category', $url);
    }

    /**
     * Parse clean URL
     * Return array((string) $target, (array) $params)
     *
     * @param string $url  Main part of a clean URL
     * @param string $last First part before the "url" OPTIONAL
     * @param string $rest Part before the "url" and "last" OPTIONAL
     * @param string $ext  Extension OPTIONAL
     *
     * @return array
     */
    protected function parseURLPage($url, $last = '', $rest = '', $ext = '')
    {
        return $this->findByURL('page', $url);
    }	
	
    /**
     * Build product URL
     *
     * @param array  $params Params
     *
     * @return array
     */
    protected function buildURLProduct($params)
    {
        $urlParts = array();

        if (!empty($params['product_id'])) {
            /** @var \XLite\Model\Product $product */
            $product = \XLite\Core\Database::getRepo('XLite\Model\Product')->find($params['product_id']);

            if (null !== $product && $product->getCleanURL()) {
                $urlParts[] = $product->getCleanURL() . '/';
            }
        }

        return array($urlParts);
    }

    /**
     * Build category URL
     *
     * @param array  $params Params
     *
     * @return array
     */
    protected function buildURLCategory($params)
    {
        $urlParts = array();

        if (!empty($params['category_id'])) {
            /** @var \XLite\Model\Product $product */
            $category = \XLite\Core\Database::getRepo('XLite\Model\Category')->find($params['category_id']);

            if (null !== $category && $category->getCleanURL()) {
                $urlParts[] = $category->getCleanURL() . '/';
            }
        }

        return array($urlParts);
    }	
	
}
